@@ -1,4 +1,4 @@
-# $Id: Manifest.pm,v 1.4 2002/12/11 06:46:25 comdog Exp $
+# $Id: Manifest.pm,v 1.7 2003/07/30 19:32:39 petdance Exp $
 package Test::Manifest;
 use strict;
 
@@ -11,8 +11,7 @@ use Exporter;
 @EXPORT    = qw(run_t_manifest);
 @EXPORT_OK = qw(get_t_files make_test_manifest manifest_name);
 
-#$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ m/(\d+) . (\d+)/x;
-$VERSION = 0.91;
+$VERSION = 0.92;
 
 my $Manifest = "t/test_manifest";
 
@@ -41,9 +40,7 @@ do the right thing.
 
 =head1 FUNCTIONS
 
-=over 4
-
-=item run_t_manifest
+=head2 C<run_t_manifest()>
 
 Run all of the files in t/test_manifest through Test::Harness:runtests
 in the order they appear in the file.
@@ -67,21 +64,21 @@ headache.
 
 sub run_t_manifest 
 	{
-    require Test::Harness;
-    require File::Spec;
+	require Test::Harness;
+	require File::Spec;
 
-    $Test::Harness::verbose = shift;
+	$Test::Harness::verbose = shift;
 
-    local @INC = @INC;
-    unshift @INC, map { File::Spec->rel2abs($_) } @_;
+	local @INC = @INC;
+	unshift @INC, map { File::Spec->rel2abs($_) } @_;
 
 	my @files = get_t_files();
 	print STDERR "Test::Manifest::test_harness found [@files]\n";
 	
-    Test::Harness::runtests( @files );
+	Test::Harness::runtests( @files );
 	}
 
-=item get_t_files()
+=head2 C<get_t_files()>
 
 In scalar context it returns a single string that you can use directly
 in WriteMakefile().
@@ -100,7 +97,7 @@ entries start with "t/".
 sub get_t_files()
 	{
 	carp( "$Manifest does not exist!" ) unless -e $Manifest;
-	return unless open my $fh, $Manifest;
+	return unless open( my $fh, $Manifest );
 	
 	my @tests = ();
 	
@@ -110,11 +107,12 @@ sub get_t_files()
 		carp( "test file begins with t/ [$_]" ) if m|^t/|;
 		push @tests, "t/$_" if -e "t/$_";
 		}
+	close $fh;
 		
 	return wantarray ? @tests : join " ", @tests;
 	}
 
-=item make_test_manifest()
+=head2 C<make_test_manifest()>
 
 Creates the test_manifest file in the t directory by reading
 the contents of the t directory.
@@ -128,7 +126,7 @@ TO DO: specify files to skip.
 sub make_test_manifest()
 	{
 	carp( "t/ directory does not exist!" ) unless -d "t";
-	return unless open my $fh, "> $Manifest";
+	return unless open( my $fh, "> $Manifest" );
 	
 	my $count = 0;
 	while( my $file = glob("t/*.t") )
@@ -137,11 +135,12 @@ sub make_test_manifest()
 		print $fh "$file\n";
 		$count++;
 		}
+	close $fh;
 	
 	return $count;
 	}
 
-=item manifest_name
+=head2 C<manifest_name()>
 
 Returns the name of the test manifest file, relative to t/
 
@@ -152,8 +151,6 @@ sub manifest_name
 	return $Manifest;
 	}
 	
-=back
-
 =head1 SOURCE AVAILABILITY
 
 This source is part of a SourceForge project which always has the
@@ -166,11 +163,11 @@ members of the project can shepherd this module appropriately.
 
 =head1 AUTHOR
 
-brian d foy, E<lt>bdfoy@cpan.orgE<lt>
+C<brian d foy>, E<lt>bdfoy@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002, brian d foy, All Rights Reserved
+Copyright 2002, C<brian d foy>, All Rights Reserved
 
 You may use and distribute this module under the same terms
 as Perl itself
